@@ -8,7 +8,13 @@
  * Version:	@(#)init.c  2.86  30-Jul-2004  miquels@cistron.nl
  * Version:     init.c 2.90 18-Jun-2018 jsmith@resonatingmedia.com
  */
-#define VERSION "2.90"
+
+/*
+Version information is not placed in the top-level Makefile by default
+*/
+#ifndef VERSION
+#define VERSION "2.91"
+#endif
 /*
  *		This file is part of the sysvinit suite,
  *		Copyright (C) 1991-2004 Miquel van Smoorenburg.
@@ -74,6 +80,7 @@
 #include "initreq.h"
 #include "paths.h"
 #include "reboot.h"
+#include "runlevellog.h"
 #include "set.h"
 
 #ifndef SIGPWR
@@ -126,7 +133,7 @@ int wrote_wtmp_reboot = 1;	/* Set when we wrote the reboot record */
 int wrote_utmp_reboot = 1;	/* Set when we wrote the reboot record */
 int wrote_wtmp_rlevel = 1;	/* Set when we wrote the runlevel record */
 int wrote_utmp_rlevel = 1;	/* Set when we wrote the runlevel record */
-int sltime = 5;			/* Sleep time between TERM and KILL */
+int sltime = WAIT_BETWEEN_SIGNALS;    /* Sleep time between TERM and KILL */
 char *argv0;			/* First arguments; show up in ps listing */
 int maxproclen;			/* Maximal length of argv[0] with \0 */
 struct utmp utproto;		/* Only used for sizeof(utproto.ut_id) */
@@ -825,7 +832,7 @@ void console_stty(void)
 #endif /* IUTF8 */
 		;
 	tty.c_oflag = OPOST|ONLCR;
-	tty.c_lflag = ISIG|ICANON|ECHO|ECHOCTL|ECHOPRT|ECHOKE;
+	tty.c_lflag = ISIG|ICANON|ECHO|ECHOCTL|ECHOE|ECHOKE;
 
 #if defined(SANE_TIO) && (SANE_TIO == 1)
 	/*
@@ -1338,6 +1345,8 @@ void check_kernel_console()
 	}    
 	if (fgets(buf, sizeof(buf), fp)) {    
 		char* p = buf;
+           if ( strstr(p, "init.autocon=1") )
+           {
 		while ((p = strstr(p, "console="))) {    
 			char* e;
 			p += strlen("console=");
@@ -1391,7 +1400,8 @@ void check_kernel_console()
 					initlog(L_VB, "added agetty on %s with id %s", dev, id);
 				}
 			}
-		}    
+		}
+            } 
 	}    
 	fclose(fp);
 	return;
@@ -1899,6 +1909,7 @@ int get_init_default(void)
 	/*
 	 *	Log the fact that we have a runlevel now.
 	 */
+        Write_Runlevel_Log(lvl);
 	return lvl;
 }
 
@@ -2014,6 +2025,7 @@ int read_level(int arg)
 	write_utmp_wtmp("runlevel", "~~", foo + 256*runlevel, RUN_LVL, "~");
 	thislevel = foo;
 	prevlevel = runlevel;
+        Write_Runlevel_Log(runlevel);
 	return foo;
 }
 
@@ -2212,7 +2224,7 @@ void re_exec(void)
 
 	/*
 	 *	We shouldn't be here, something failed. 
-	 *	Bitch, close the state pipe, unblock signals and return.
+	 *	Close the state pipe, unblock signals and return.
 	 */
 	init_freeenv(env);
 	close(fd);
@@ -2278,6 +2290,7 @@ void fifo_new_level(int level)
 			setproctitle("init [%c]", (int)runlevel);
 		}
 	}
+        Write_Runlevel_Log(runlevel);
 }
 
 
@@ -2566,6 +2579,7 @@ void boot_transitions()
 		prevlevel = oldlevel;
 		setproctitle("init [%c]", (int)runlevel);
 	}
+        Write_Runlevel_Log(runlevel);
   }
 }
 
@@ -2677,6 +2691,7 @@ void process_signals()
 			setproctitle("init [%c]", (int)runlevel);
 			DELSET(got_signals, SIGHUP);
 		}
+                Write_Runlevel_Log(runlevel);
 	}
   }
   if (ISMEMBER(got_signals, SIGUSR1)) {
@@ -3000,6 +3015,12 @@ int main(int argc, char **argv)
 	else
   		p = argv[0];
 
+        if ( (argc == 2) && (! strcmp(argv[1], "--version") ) )
+        {
+           printf("SysV init version: %s\n\n", VERSION);
+           exit(0);
+        }
+
 	/* Common umask */
 	umask(umask(077) | 022);
 
