@@ -144,7 +144,9 @@ void tcinit(struct console *con)
 		cfsetispeed(tio, ispeed);
 		cfsetospeed(tio, ospeed);
 
+#ifndef __GNU__
 		tio->c_line         = 0;
+#endif
 		tio->c_cc[VTIME]    = 0;
 		tio->c_cc[VMIN]     = 1;
 
@@ -203,7 +205,7 @@ void tcinit(struct console *con)
 	tio->c_cc[VEOF]     = CEOF;
 # ifdef VSWTC
 	tio->c_cc[VSWTC]    = _POSIX_VDISABLE;
-# else
+# elif defined(VSWTCH)
 	tio->c_cc[VSWTCH]   = _POSIX_VDISABLE;
 # endif
 	tio->c_cc[VSTART]   = CSTART;
@@ -261,7 +263,7 @@ void tcfinal(struct console *con)
 	tio->c_cc[VEOF]     = CEOF;
 #ifdef VSWTC
 	tio->c_cc[VSWTC]    = _POSIX_VDISABLE;
-#else
+#elif defined(VSWTCH)
 	tio->c_cc[VSWTCH]   = _POSIX_VDISABLE;
 #endif
 	tio->c_cc[VSTART]   = CSTART;
